Латинизация русской кириллицы
=============================

Используется следующее соответствие:
- *а* —  *a*;
- *б* —  *b*;
- *в* —  *v*;
- *г* —  *g*;
- *д* —  *d*;
- *е* — *ye*, если стоит после *ь*;
- *е* — *qe*, если стоит после *ъ*;
- *е* —  *e*, во всех остальных случаях;
- *ё* — *yo*, если стоит в начале слов, после гласных и *ь*;
- *ё* — *qo*, если стоит после *ъ*;
- *ё* —  *o*, если не йотирована и стоит после непарных твердых согласных;
- *ё* — *ho*, во всех остальных случаях;
- *ж* —  *j*;
- *з* —  *z*;
- *и* —  *i*;
- *й* —  *y*;
- *к* —  *k*;
- *л* —  *l*;
- *м* —  *m*;
- *н* —  *n*;
- *о* —  *o*;
- *п* —  *p*;
- *р* —  *r*;
- *с* —  *s*;
- *т* —  *t*;
- *у* —  *u*;
- *ф* —  *f*;
- *х* —  *x*;
- *ц* —  *c*;
- *ч* — *ch*;
- *ш* —  *w*;
- *щ* — *wh*;
- *ъ* —  *q*, не требуется;
- *ы* —  *i*, если стоит после непарной твердой согласной;
- *ы* — *qi*, во всех остальных случаях;
- *ь* —  *h*, если стоит после согласной и она требует смягчения, в других случаях не требуется;
- *э* —  *e*, если стоит после непарной твердой согласной;
- *э* — *qh*, если стоит перед *а*, *о*, *у*, *и*, *е*;
- *э* —  *q*, во всех остальных случаях;
- *ю* — *yu*, если стоит в начале слов, после гласных и *ь*;
- *ю* — *qu*, если стоит после *ъ*;
- *ю* —  *u*, если не йотирована и стоит после непарных твердых согласных;
- *ю* — *hu*, во всех остальных случаях;
- *я* — *ya*, если стоит в начале слов, после гласных и *ь*;
- *я* — *qa*, если стоит после *ъ*;
- *я* —  *a*, если не йотирована и стоит после непарных твердых согласных;
- *я* — *ha*, во всех остальных случаях.

Хотя соответствие алгоритмическое, но в некоторых случаях их следует применять фонематически, применяя следующие правила:
- Буквосочетание *ьо* после *л* или *н*, встречающееся в заимствованных словах, которое произносится с йотирование передается как *yo*.
- Если на письме в заимствованных словах предполагается смягчение согласной, которое не происходит, это можно отражать отходом при латинизации от кириллического написания. Но, в основном, рекомендуется сохранять буквенное соответствие с кириллическим написанием, так как часто одной из норм является смягченное произношение. Например, допускаются два варианта произношения: со смягченной согласной перед *е* и с несмягчённой в слове *бактерицидный*.
- В словах *веешь*, *смеешь*, *вошь* и подобных, там где мягкий знак не несёт орфоэпической функции он не транслитерируется, иначе проставление *h* меняло бы букву, например, с *ш* (*w*) на *щ* (*wh*).
- В словах с *ъ* на конце, имитирующих старую орфографию, твёрдый знак опускается.

Правила разделительных знаков следующие, что является просто следствием принятых соответствий:
- Разделительные знаки перед йотированными гласными могут обозначаться *y*, *q*. Буква *y* смягчает предыдущую согласную и используется для разделительного *ь*. Буква *q* используется соответственно для разделительного *ъ*. Так как *q* используется как *э*, то если после *э* идёт гласная, она отделяется *h*, чтобы различать *э* и *ъ*.

Примеры:

- авдотья - avdotya;
- отъявленный - otqavlennqiy;
- бактерицидный - baktericidnqiy;
- вьюга - vyuga;
- юг - yug;
- эра - qra;
- эон - qhon;
- цирк - cirk;
- жюри - juri;
- щебетать - whebetath;
- парашют - parawut;
- аллофон - allofon;
- съезд - sqezd;
- метр - metr;
- мэтр - mqtr;
- лук - luk;
- люк - lhuk;
- клык - klqik;
- клик - klik;
- клён - klhon;
- клон - klon;
- раса - rasa;
- ряса - rhasa;
- пот - pot;
- под - pod;
- топ - top;
- топь - toph;
- йод - yod;
- яд - yad;
- подыграть - podqigrath;
- вожжи - vojji;
- жужжать - jujjath;
- объём - obqom;
- бельё - belyo;
- подъезд - podqezd;
- отребье - otrebye;
- выемка - vqiemka;
- гальюн - galyun;
- веет - veet;
- веешь - veew;
- епархия - yeparxiya;
- ералаш - eralaw;
- красивые - krasivqie;
- коммерсантъ - kommersant;
- тэер - tqeer;
- гэй - gqy;
- гей - gey;
- МЭИ - MQHI.
- каньон - kanyon;

Примеры использования кода:
===========================

При латинизации выполняется нормализация юникода, делать её вручную не нужно. См. пример 2.


```python3
from ayum.translit import to_latin

# 1
print(to_latin('Объёмом 5 литров')) # prints 'Оbqomom 5 litrov'

# 2
print(to_latin('\u0435\u0308')) # prints 'yo'
print(to_latin('\u0451'))       # prints 'yo'

```
